==> h5-0.7.0.tar.gz: h5-0.7.0/h5/__init__.py <==
# -*- coding: utf-8 -*-
"""HDF5 functions, and utils, and generators, OH MY!"""
from h5py import __version__ as __h5py_version__

from h5._meta import __version__
from h5.core import (
    attrs_dict as attrs_dict,
    attrs_gen as attrs_gen,
    attrs_gen_from_fspath as attrs_gen_from_fspath,
    datasets as datasets,
    datasets_dict as datasets_dict,
    datasets_gen as datasets_gen,
    datasets_gen_from_fspath as datasets_gen_from_fspath,
    groups as groups,
    groups_gen as groups_gen,
    groups_gen_from_fspath as groups_gen_from_fspath,
    h5_attrs_dict as h5_attrs_dict,
    h5_attrs_gen as h5_attrs_gen,
    h5_attrs_gen_from_fspath as h5_attrs_gen_from_fspath,
    h5_datasets_dict as h5_datasets_dict,
    h5_datasets_gen as h5_datasets_gen,
    h5_datasets_gen_from_fspath as h5_datasets_gen_from_fspath,
    h5iter as h5iter,
    h5py_obj_attrs_gen as h5py_obj_attrs_gen,
    h5py_obj_dataset_gen as h5py_obj_dataset_gen,
    h5py_obj_gen as h5py_obj_gen,
    h5py_obj_groups_gen as h5py_obj_groups_gen,
)

__all__ = (
    "__h5py_version__",
    "__version__",
    "attrs_dict",
    "attrs_gen",
    "attrs_gen_from_fspath",
    "chain",
    "datasets",
    "datasets_dict",
    "datasets_gen",
    "datasets_gen_from_fspath",
    "groups",
    "groups_gen",
    "groups_gen_from_fspath",
    "h5_attrs_dict",
    "h5_attrs_gen",
    "h5_attrs_gen_from_fspath",
    "h5_datasets_dict",
    "h5_datasets_gen",
    "h5_datasets_gen_from_fspath",
    "h5iter",
    "h5py_obj_attrs_gen",
    "h5py_obj_dataset_gen",
    "h5py_obj_gen",
    "h5py_obj_groups_gen",
)

==> h5-0.8.0.tar.gz: h5-0.8.0/h5/__init__.py <==
# -*- coding: utf-8 -*-
"""HDF5 functions, and utils, and generators, OH MY!"""
from h5py import AttributeManager, Dataset, File, Group, __version__ as __h5py_version__

from h5._meta import __version__
from h5.core import (
    attrs_dict as attrs_dict,
    attrs_gen as attrs_gen,
    attrs_gen_from_fspath as attrs_gen_from_fspath,
    datasets as datasets,
    datasets_dict as datasets_dict,
    datasets_gen as datasets_gen,
    datasets_gen_from_fspath as datasets_gen_from_fspath,
    groups as groups,
    groups_gen as groups_gen,
    groups_gen_from_fspath as groups_gen_from_fspath,
    h5_attrs_dict as h5_attrs_dict,
    h5_attrs_gen as h5_attrs_gen,
    h5_attrs_gen_from_fspath as h5_attrs_gen_from_fspath,
    h5_datasets_dict as h5_datasets_dict,
    h5_datasets_gen as h5_datasets_gen,
    h5_datasets_gen_from_fspath as h5_datasets_gen_from_fspath,
    h5iter as h5iter,
    h5py_obj_attrs_gen as h5py_obj_attrs_gen,
    h5py_obj_dataset_gen as h5py_obj_dataset_gen,
    h5py_obj_gen as h5py_obj_gen,
    h5py_obj_groups_gen as h5py_obj_groups_gen,
    is_dataset as is_dataset,
    is_file as is_file,
    is_group as is_group,
    is_h5py_dataset as is_h5py_dataset,
    is_h5py_file as is_h5py_file,
    is_h5py_group as is_h5py_group,
)

__all__ = (
    "AttributeManager",
    "Dataset",
    "File",
    "Group",
    "__h5py_version__",
    "__version__",
    "attrs_dict",
    "attrs_gen",
    "attrs_gen_from_fspath",
    "chain",
    "datasets",
    "datasets_dict",
    "datasets_gen",
    "datasets_gen_from_fspath",
    "groups",
    "groups_gen",
    "groups_gen_from_fspath",
    "h5_attrs_dict",
    "h5_attrs_gen",
    "h5_attrs_gen_from_fspath",
    "h5_datasets_dict",
    "h5_datasets_gen",
    "h5_datasets_gen_from_fspath",
    "h5iter",
    "h5py_obj_attrs_gen",
    "h5py_obj_dataset_gen",
    "h5py_obj_gen",
    "h5py_obj_groups_gen",
    "is_dataset",
    "is_file",
    "is_group",
    "is_h5py_dataset",
    "is_h5py_file",
    "is_h5py_group",
)
